# artifician package

## Subpackages

::: {.toctree maxdepth="4"}
artifician.extractors artifician.processors
:::

## artifician.dataset module

::: {.automodule members="" undoc-members="" show-inheritance=""}
artifician.dataset
:::

## artifician.feature_definition module

::: {.automodule members="" undoc-members="" show-inheritance=""}
artifician.feature_definition
:::
